Master Horologer
Description: Horozima is now Masterhorologer

## MENU

- HOME
- ABOUT US
- NOVELTIES 2015
- FEATURED BRANDS
- NEWS
- PRODUCT ARCHIVES
- MORE INFO
- JEWELLERY
- GUEST COLUMN
- VINTAGE GALLERY
- FEATURED BOUTIQUES
- CONTACT US
- NOVELTIES 2014

## Sunday, December 6, 2015

### HUBLOT celebrates the grand opening of Taipei boutique as well as the 10th anniversary of the iconic BIG BANG

Hublot, the Swiss luxury watchmaker has recently celebrated the grand opening of its Taipei 101 boutique as well as the 10th anniversary of the iconic Big Bang. 10 years have passed since Hublot unveiled its first Big Bang - the Big Bang Gold Ceramic. The Big Bang, next to various astonishing Grandes Complications are presented to commemorate this remarkable milestone. To continue the spirit of “Hublot Loves Baseball”, Taiwanese famous Major League Baseball pitcher Wei-Yin Chen was the guest of honor of the ribbon-cutting ceremony along with Loïc Biver. In order to give back to the younger generation, Hublot supports the Aboriginal Little League Baseball team from Taichung with Baseball equipment bags. These junior players also brought their splendid performance of the unique traditional Tayal Tribe “battle dance” to celebrate the grand opening of Hublot’s Taiwan boutique store.
Hublot Taipei 101 boutique offers a subtle interplay of materials, fabrics and styles that give the store a luxurious and elegant ambiance. The combination offers a warm, gentle feel in nuances of grey and black. The materials, silver brushed Oakwood and wool carpets with silk lining covering the ebony chrome steel wall, Italian handmade chairs and leather sofas, Murano Italian-made lamps and chandeliers, are representing the brand’s core concept "Art of Fusion" which allows customers to immerse themselves in the world of Hublot. The walls are decorated with Pop Art inspired works that bring touches of bright colours and take an off-beat look at the brand's most famous models.
To celebrate the 10th anniversary of the Big Bang collection, several iconic complicated watches were on display in Taiwan to celebrate this grand opening. The Big Bang UNICO Full Magic Gold, housing the in-house UNICO movement in the brand's unique, scratch-resistant 18K gold watchcase (a genius combination of gold and ceramic).
The Big Bang Tourbillon 5-Day Power Reserve All Black, was also unveiled. The first Tourbillon in the new generation Big Bang line, with a beautiful skeleton movement and an added practical power reserve indicator function on the dial side. Designed, developed and produced entirely by Hublot’s micro-mechanics, engineers and watchmakers, this proprietary movement is a traditional tourbillon with a cage measuring 13.6 mm in diameter – a minute tourbillon that performs one revolution every minute – and whose construction featuring a barrette on the dial side ensures its stability. Whereas the sparkling Big Bang UNICO King Gold Pavé with white diamonds, and the Spirit of Big Bang King Gold Pavé, which is a rectangular with rounded sides that resembles the appearance of a barrel, take after the classic design of Big Bang collection with glimmering diamonds that is not only elegant but graceful.
On the other hand, the Big Bang Broderie Steel Diamonds, award winning “Ladies’ Watch” prize of the Grand Prix de l’Horlogerie de Genève 2015 , is an extraordinary watch piece created by the joint force of Hublot and Bischoff, the Swiss flagship company. Together, the creative teams of the two houses thus developed an exclusive pattern that could join with the Big Bang’s iconic design. A rebel spirit featuring a skull design on a dial framed with 11 diamonds, with soft arabesques for the bezel and the strap, the technical execution alone required several months of research and development.
Continuing the spirits of jointing sport stars that carry characteristics, Hublot invited the most popular Taiwanese professional MLB baseball pitcher Wei-Yin Chen as the guest of honor of the ribbon-cutting ceremony. Wei-Yin Chen, born in Taiwan, was able to make it to the international stage with his advantage of being a left-handed specialist and his precise and stable performance.
At the Taipei 101 boutique opening, Loïc Biver, General Manager of Hublot Greater China, joined by the Chinese Taipei Baseball Association, 101 Shopping Mall representatives, and Wei-Yin Chen presented baseball various equipment to the Aboriginal Little League Baseball team. As thank you gesture, the junior players performed their traditional battle dance.
Older Posts Home
Subscribe to: Posts (Atom)

## SEARCH OUR LUXURY WATCH DATABASE

## Popular Posts

- MEW 005 DEPTH PILOT
  MEW Watches, a young brand that produces tactical watches, announces its new model: the MEW 005 DEPTH PILOT. The Mew Tactical 005 Depth Pilo...
- Czapek & Cie Quai des Bergues Collection
  In November this year, Switzerland’s traditional watchmaking industry welcomes revival of the legendary Czapek & Cie brand name. A well ...
- Masterpiece London 2015 Opens with Record Attendees, Significant Sales across the Board and Major Unveilings
  The Preview Day of the sixth edition of Masterpiece London ended with reports of record visitor numbers and strong sales across the board. T...
- Corum Miss Golden Bridge Ceramic
  In 2015, Corum celebrates the 35 years of its mythical movement Golden Bridge. An anniversary conjugated to the feminine and expressed by a ...
- Haldor Abissi
  Slovenia based young watch brand presents Abissi, a Swiss Made automatic dive watch designed for professional diving enthusiasts. Establishe...
- ArtyA Son of a Gun Skulls
  This stainless steel timepiece from Swiss watch brand ArtyA features 11 hand crafted skulls on the dial that appear to be suspended in a mo...
- Corum Admiral’s Cup AC-One 45 Tides
  An icon among sea-lovers now returns in a reworked design: the Admiral’s Cup AC One 45 Tides watch. 21 years after its launch, this model wi...
- CITIZEN Eco Drive (AO9030-05E)
  Japanese watch maker CITIZEN presents the elegant vintage-inspired timepiece AO9030-05E, which is inspired by the spirit of the adventurous ...
- JP Watch Design - Bearing Collection
  Australia based contemporary watch brand JP WATCH DESIGN Launches ‘The Bearing’ Collection in partnership with World Land Trust & Water ...
- Luminox P-38 Lightning GMT (9420) & Chronograph (9440) Series
  Utilizing aircraft-inspired details, the watches of the Luminox AIR series pay tribute to some of the most remarkable strategic aircraft in ...